#!/usr/bin/env python

import argparse
import requests
from requests.auth import HTTPDigestAuth
import json

parser = argparse.ArgumentParser(description='Process some integers.')
parser.add_argument('integers', metavar='N', type=int, nargs='+',
                    help='an integer for the accumulator')
parser.add_argument('--sum', dest='accumulate', action='store_const',
                    const=sum, default=max,
                    help='sum the integers (default: find the max)')

args = parser.parse_args()
print(args.accumulate(args.integers))

#
# Actual Code
#

url = 'http://127.0.0.1:32768/management'
auth = HTTPDigestAuth('wildfly', 'wildfly')
headers = {'content-type': 'application/json'}
payload = {
  'operation': 'read-resource',
  'recursive': True,
  json.pretty' => true'
  }

result = requests.post(url,
                       json=payload,
                       headers=headers,
                       auth=auth)

result = requests.post(url,
                       data=json.dumps(payload),
                       headers=headers,
                       auth=auth)
# Pretty Print the JSON
formatted = json.dumps(result.json(), indent=4, sort_keys=True)
print(formatted)

# class ClassName(apiClient):
# Python likes () at the end of its methods
# Eg. result.json()['result'].keys()

# Parsing JSON from a String, the hard way...
# my_json = result.content.decode('utf8').replace("'", '"')


# class WildFly(requests):

def api_client(request):
    url = 'http://127.0.0.1:32768/management'
    auth = HTTPDigestAuth('wildfly', 'wildfly')
    headers = {'content-type': 'application/json'}
    result = requests.post(url,
                           json=request,
                           headers=headers,
                           auth=auth)
    return result


def cli(cmd, output=True):
    request = build(cmd)
    resp = api_client(request)
    if output:
        # Pretty Print the JSON
        formatted = json.dumps(resp.json(), indent=4, sort_keys=True)
        print(formatted)
    return resp


def build(cmd):
    cmd = str(cmd).split(':')
    body = {}
    body['address'] = address(cmd[0])
    body['json.pretty'] = True
    if len(cmd) == 2:
        for k, v in operation(cmd[1]).items():
            body[k] = v
    return dict(body)


def operation(op):
    resp = {}
    op = str(op).split('(', 1)
    resp['operation'] = op[0]
    if len(op) == 1:
        return resp
    params = op[1].replace(')', '').split(',')
    # Remove Empty Elements
    params = list(filter(None, params))
    for x in params:
        x = x.split('=')
        if len(x) == 2:
            resp[x[0]] = x[1]
        else:
            resp[x[0]] = True
    return dict(resp)


def address(addr):
    addr = str(addr).replace('=', '/').split('/')
    # Remove Empty Elements
    return list(filter(None, addr))


cli(':read-resource(recursive)')
